@@ -26,7 +26,7 @@ except:
 	_c = False
 
 __all__ = ['status']
-__version__ = '3.3.3'
+__version__ = '3.4.1'
 
 if hasattr(_sys, 'runningPPF'):
 	PyProtFramework = True
@@ -40,6 +40,7 @@ if not _os.path.split(_os.path.split(__file__)[0])[1] == 'prot':
 	__version__ += '-unofficial'
 else:
 	status.append('official')
+
 if _os.path.split(_os.path.split(__file__)[0])[1] == 'lightprot':
 	status.append('light')
 	__version__ = __version__.replace('unofficial', 'light')
@@ -358,9 +359,11 @@ def runAsMain(args=None):
 @addBuiltins
 def printMsg(msg='', color=None, end='\n', file=None, colorize=True, prefix=True):
 	global _c
-	if 'light' in status and 'haveProt' in status and _prt is not None:
-		settings.colorize = _prt.settings.colorize
-	if settings.colorize == 'off':
+	try:
+		if 'light' in status and 'haveProt' in status and _prt is not None:
+			settings.colorize = _prt.settings.colorize
+	except: pass
+	if settings.colorize == 'off' or not _sys.stdout == _sys.__stdout__:
 		_c = False
 	if prefix and settings.printMsgPrefix:
 		msg = str(settings.printMsgPrefix) + str(msg)
@@ -436,6 +439,18 @@ def netScan(port=80, timeout=0.5):
 				hostsAvail.append((host, p))
 	return hostsAvail
 
+@appendAll
+def netAttack(addr, times):
+	sock = _socket.socket()
+	val1 = ValueWidget('starting')
+	prog = Progress(maxVal=times, msgForm='($VAL/$MAX) $1 $PERC% $MSG', replaces=[['$1', val1]], inline=True)
+	for t in range(times):
+		val1.value = 'connecting to ' + str(addr[0]) + ':' + str(addr[1]) + '...'
+		sock.connect(addr)
+		val1.value = 'disconnecting from ' + str(addr[0]) + ':' + str(addr[1]) + '...'
+		sock.close()
+	del sock
+
 @appendAll
 @addBuiltins
 class Matrix(list):
@@ -1348,7 +1363,7 @@ class Progress(object):
 		msg = self.do_replace(replaces)
 		if self.color and verifyColor(self.color, False):
 			msg = '-' + self.color + msg + '*end'
-		if self.inline:
+		if self.inline and _sys.stdout == _sys.__stdout__:
 			self.printInline(msg)
 		else:
 			printMsg(msg)
